# -*- coding: utf-8 -*-
# Generated by Django 1.11.23 on 2019-09-10 12:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('NEMO', '0007_version_1_15_0'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserPreferences',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('attach_created_reservation', models.BooleanField(default=False, help_text='Whether or not to send a calendar invitation when creating a new reservation', verbose_name='created_reservation_invite')),
                ('attach_cancelled_reservation', models.BooleanField(default=False, help_text='Whether or not to send a calendar invitation when cancelling a reservation', verbose_name='cancelled_reservation_invite')),
            ],
            options={
                'verbose_name': 'User preferences',
                'verbose_name_plural': 'User preferences',
            },
        ),
        migrations.AlterField(
            model_name='tool',
            name='policy_off_between_times',
            field=models.BooleanField(default=False, help_text='Check this box to disable policy rules every day between the given times'),
        ),
        migrations.AlterField(
            model_name='tool',
            name='policy_off_weekend',
            field=models.BooleanField(default=False, help_text='Whether or not policy rules should be enforced on weekends'),
        ),
        migrations.AddField(
            model_name='user',
            name='preferences',
            field=models.OneToOneField(null=True, on_delete=django.db.models.deletion.CASCADE, to='NEMO.UserPreferences'),
        ),
    ]
