{% extends 'base.html' %}
{% load humanize %}
{% block title %}Reservation abuse{% endblock %}
{% block content %}
	<h1>Reservation abuse for {{ abuser }}</h1>
	<table class="table table-condensed table-borderless">
		<tr><th>Tool</th><th>Advance notice</th><th>Penalty</th><th>Original start time</th><th>Reservation ID</th></tr>
		{% for a in abuses %}
			<tr><td>{{ a.tool_name }}</td><td>{{ a.delta }}</td><td>{{ a.penalty|floatformat }}</td><td>{{ a.start }}</td><td>{{ a.id }}</td></tr>
		{% endfor %}
	</table>
{% endblock %}