$('#sidebar .sidebar-status-icon').remove();
{% for tool in tool_summary %}
	{% if tool.in_use %}
		$('a[data-tool-id={{ tool.id }}]').append('<span class="glyphicon glyphicon-user primary-highlight sidebar-status-icon" title="{{ tool.user }} is using this tool"></span>');
	{% endif %}

	{% if tool.delayed_logoff_in_progress %}
		$('a[data-tool-id={{ tool.id }}]').append('<span class="glyphicon glyphicon-time primary-highlight sidebar-status-icon" title="Delayed logoff is in effect for this tool"></span>');
	{% endif %}
	{% if tool.scheduled_outage %}
		$('a[data-tool-id={{ tool.id }}]').append('<span class="glyphicon glyphicon-time danger-highlight sidebar-status-icon" title="A scheduled outage is in effect for this tool"></span>');
	{% endif %}

	{% if tool.required_resource_is_unavailable %}
		$('a[data-tool-id={{ tool.id }}]').append('<span class="glyphicon glyphicon-leaf danger-highlight sidebar-status-icon" title="This tool is unavailable because a required resource is unavailable"></span>');
	{% elif tool.nonrequired_resource_is_unavailable %}
		$('a[data-tool-id={{ tool.id }}]').append('<span class="glyphicon glyphicon-leaf warning-highlight sidebar-status-icon" title="This tool is operating in a diminished capacity because an optional resource is unavailable"></span>');
	{% endif %}

	{% if tool.operational == False %}
		$('a[data-tool-id={{ tool.id }}]').append('<span class="glyphicon glyphicon-fire danger-highlight sidebar-status-icon" title="This tool is shut down"></span>');
	{% elif tool.problematic == True %}
		$('a[data-tool-id={{ tool.id }}]').append('<span class="glyphicon glyphicon-wrench warning-highlight sidebar-status-icon" title="This tool requires maintenance"></span>');
	{% endif %}
{% endfor %}