# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-11-21 14:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('NEMO', '0005_version_1_4_0'),
    ]

    operations = [
        migrations.AddField(
            model_name='tool',
            name='grant_badge_reader_access_upon_qualification',
            field=models.CharField(blank=True, help_text='Badge reader access is granted to the user upon qualification for this tool.', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='tool',
            name='grant_physical_access_level_upon_qualification',
            field=models.ForeignKey(blank=True, help_text='The designated physical access level is granted to the user upon qualification for this tool.', null=True, on_delete=django.db.models.deletion.CASCADE, to='NEMO.PhysicalAccessLevel'),
        ),
    ]
