{% extends 'base.html' %}
{% block title %}Reservation confirmed{% endblock %}
{% block content %}
	<h3>Reservation confirmed!</h3>
	<div class="alert alert-success" role="alert">
		<strong>{{ new_reservation.tool }}</strong><br>
		{{ new_reservation.start|date:"l, F jS" }}<br>
		Starting {{ new_reservation.start|time }}<br>
		Ending {{ new_reservation.end|time }}<br>
	</div>
	<div style="font-size:x-large">
		<p><a href="{% url 'landing' %}"><span class="glyphicon glyphicon-home" style="color:#22b14c"></span> Return to homepage</a></p>
		<p><a href="{% url 'view_calendar' new_reservation.tool.id %}"><span class="glyphicon glyphicon-calendar" style="color:#22b14c"></span> View the {{ new_reservation.tool }} calendar</a></p>
	</div>
{% endblock %}